==> uxkit-0.0.2.tgz: package/built/UXKit/TableViewCell.js <==
/// <reference path="../../typings/tsd.d.ts"/>
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
import * as React from "react";
import * as RN from "react-native";
import { View } from "./View";
import { PixelLine } from "./PixelLine";
import { Image, ImageView } from "./ImageView";
import { TextButton } from "./Button";
import { PresetColor } from "./Types";
import { ControlEvents, TableViewCellAccessoryType, ImageRenderingMode } from "./Enum";
export class TableViewCellReusingValues {
    constructor() {
        this.top = new RN.Animated.Value(0);
        this.height = new RN.Animated.Value(0);
        this.other = {};
        this.topValue = 0;
        this.heightValue = 0;
        this.otherValues = {};
    }
}
/**
 * TableViewCell
 */
export class TableViewCell extends View {
    constructor(props) {
        super(props);
        this.visibleProps = {};
        this.data = {};
        this.loaded = false;
        this.contentViewMarginLeft = new RN.Animated.Value(0.0);
        this.contentViewMarginRight = new RN.Animated.Value(0.0);
        this.editImp = new TableViewCellEditImp(this);
    }
    view() {
        return (React.createElement(RN.View, {style: { backgroundColor: "#ffffff00" }}));
    }
    componentDidMount() {
        if (this.props.reusingValue !== undefined) {
            this.props.reusingValue.other.reusingCell = this;
        }
    }
    accessoryView() {
        if (this.visibleProps.accessoryType === TableViewCellAccessoryType.DisclosureIndicator) {
            return (React.createElement(ImageView, {image: Image.resource(require("./Assets/ux_disclosureIndicator@2x.png")), frame: { cy: 0, mx: 0, width: 28 }}));
        }
        else if (this.visibleProps.accessoryType === TableViewCellAccessoryType.Checkmark) {
            return (React.createElement(ImageView, {image: Image.resource(require("./Assets/ux_checkmark@2x.png")).imageWithRenderingMode(ImageRenderingMode.Template), frame: { cy: 0, mx: 0, width: 28 }}));
        }
        else {
            return null;
        }
    }
    separatorView() {
        let marginLeft = this.props.tableView.props.separatorInset ? this.props.tableView.props.separatorInset.left : 0.0;
        let marginRight = this.props.tableView.props.separatorInset ? this.props.tableView.props.separatorInset.right : 0.0;
        return (React.createElement(PixelLine, {style: { flex: 1, marginLeft: marginLeft, marginRight: marginRight }}));
    }
    render() {
        if (this.props.tableView.props.allowsSelection === false) {
            return this.view();
        }
        if (RN.Platform.OS == "android" && RN.Platform.Version < 19) {
            let selectedBackgroundColor = this.state ? this.state.selectedBackgroundColor : undefined;
            return (React.createElement(RN.View, __assign({style: { flex: 1, flexDirection: "row", backgroundColor: selectedBackgroundColor === undefined ? this.props.backgroundColor : selectedBackgroundColor }}, this.editImp.requestResponder()), React.createElement(RN.View, {style: { flex: 1, flexDirection: "column", backgroundColor: "#ffffff00" }}, this.view(), this.separatorView()), this.accessoryView()));
        }
        if (this.props.tableView.props.allowsEditing && this.canPerformAction() !== false) {
            let selectedBackgroundColor = this.state ? this.state.selectedBackgroundColor : undefined;
            let editing = this.state ? this.state.editing : false;
            return (React.createElement(RN.View, {style: { flex: 1, backgroundColor: selectedBackgroundColor }}, editing ? this.actionView() : null, React.createElement(RN.Animated.View, __assign({style: { flex: 1, flexDirection: "row", backgroundColor: selectedBackgroundColor === undefined ? this.props.backgroundColor : "#ffffff00", marginLeft: this.contentViewMarginLeft, marginRight: this.contentViewMarginRight }}, this.editImp.requestResponder()), React.createElement(RN.View, {style: { flex: 1, flexDirection: "column", backgroundColor: "#ffffff00" }}, this.view(), this.separatorView()), this.accessoryView())));
        }
        else {
            return (React.createElement(RN.TouchableHighlight, {style: { flex: 1 }, underlayColor: this.visibleProps.selectionColor ? this.visibleProps.selectionColor : "#e2e2e2", onPress: () => {
                this.onSelected();
            }}, React.createElement(RN.View, {style: { flex: 1, flexDirection: "row", backgroundColor: "#ffffff00" }}, React.createElement(RN.View, {style: { flex: 1, flexDirection: "column", backgroundColor: "#ffffff00" }}, this.view(), this.separatorView()), this.accessoryView())));
        }
    }
    reload() {
        if (this.props.reusingValue !== undefined) {
            this.visibleProps = !!this.props.reusingValue.other.arguments.visibleProps ? this.props.reusingValue.other.arguments.visibleProps : {};
            this.data = !!this.props.reusingValue.other.arguments.cellData ? this.props.reusingValue.other.arguments.cellData : {};
            this.forceUpdate();
        }
        this.loaded = true;
    }
    onSelected() {
        if (TableViewCell.editingCell && TableViewCell.editingCell.editImp && TableViewCell.editingCell.editImp.active) {
            TableViewCell.editingCell.endEditing();
            return;
        }
        this.props.tableView.hideIndicatorView(false);
        this.props.tableView && this.props.tableView.props.delegate && this.props.tableView.props.delegate.didSelectRowAtIndexPath && this.props.tableView.props.delegate.didSelectRowAtIndexPath(this.props.tableView, this.props.reusingValue.other.indexPath);
    }
    actionView() {
        return (React.createElement(View, {frame: { y: 0, my: 0, mx: 0, width: 66 }}, React.createElement(TextButton, {backgroundColor: PresetColor.destroyColor, tintColor: "white", title: "删除", style: { flex: 1 }, handler: (event) => {
            if (event === ControlEvents.TouchUpInside) {
                this.onDelete();
            }
        }})));
    }
    canPerformAction() {
        return true;
    }
    endEditing() {
        if (this.editImp.active) {
            this.editImp.end(0, 0);
        }
    }
    onDelete() {
        this.endEditing();
    }
}
TableViewCell.defaultProps = Object.assign({}, View.defaultProps, {
    backgroundColor: "#ffffff",
});
// editing
TableViewCell.editingCell = undefined;
/**
 * TableViewCellEditImp
 */
class TableViewCellEditImp {
    constructor(cell) {
        this.recognized = false;
        this.canceled = false;
        this.prevCanceled = false;
        this.active = false;
        this.cell = cell;
        this.panResponder = RN.PanResponder.create(this.panHandlers());
    }
    requestResponder() {
        return this.panResponder.panHandlers;
    }
    panHandlers() {
        return {
            onStartShouldSetPanResponder: (event, state) => {
                if (event.nativeEvent.pageX < 44) {
                    return false;
                }
                return true;
            },
            onStartShouldSetPanResponderCapture: (event, state) => {
                if (event.nativeEvent.pageX < this.cell.props.backTouchingArea) {
                    return false;
                }
                return true;
            },
            onMoveShouldSetPanResponder: (event, state) => {
                if (event.nativeEvent.pageX < this.cell.props.backTouchingArea) {
                    return false;
                }
                return true;
            },
            onMoveShouldSetPanResponderCapture: (event, state) => {
                if (event.nativeEvent.pageX < this.cell.props.backTouchingArea) {
                    return false;
                }
                return true;
            },
            onPanResponderGrant: (event, state) => {
                if (this.active) {
                    return;
                }
                this.prevCanceled = false;
                if (TableViewCell.editingCell !== undefined) {
                    this.prevCanceled = true;
                    TableViewCell.editingCell.endEditing();
                    TableViewCell.editingCell = undefined;
                }
                this.recognized = false;
                this.canceled = false;
                clearTimeout(this.highlightTimer);
                this.highlightTimer = setTimeout(() => {
                    if (!this.canceled) {
                        this.cell.setState({
                            selectedBackgroundColor: "#e2e2e2"
                        });
                    }
                }, 100);
            },
            onPanResponderMove: (event, state) => {
                if (this.active) {
                    return;
                }
                if (Math.abs(state.dy) < 11.0 && Math.abs(state.dx) > 4.0) {
                    if (!this.recognized) {
                        clearTimeout(this.highlightTimer);
                        this.cell.setState({
                            selectedBackgroundColor: undefined,
                            editing: true,
                        });
                    }
                    this.recognized = true;
                }
                if (this.recognized) {
                    this.move(state.dx);
                }
            },
            onPanResponderTerminationRequest: (event, state) => {
                if (Math.abs(state.dy) < 11.0 && Math.abs(state.dx) < 4.0) {
                    return false;
                }
                return !this.recognized;
            },
            onPanResponderRelease: (event, state) => {
                if (!this.recognized && !this.active && Math.abs(state.dx) < 8.0 && Math.abs(state.dy) < 8.0) {
                    !this.prevCanceled && this.cell.onSelected();
                }
                this.end(state.dx, state.vx);
            },
            onPanResponderTerminate: (event, state) => {
                this.end(state.dx, state.vx);
            },
        };
    }
    move(dx) {
        let width = this.cell.actionView().props.frame.width;
        let val = Math.max(-width, Math.min(15.0, dx));
        this.cell.contentViewMarginLeft.setValue(val);
        this.cell.contentViewMarginRight.setValue(-val);
    }
    end(dx, vx) {
        let width = this.cell.actionView().props.frame.width;
        this.cell.setState({
            selectedBackgroundColor: undefined,
        });
        if (this.recognized && (-dx > width / 2.0 || vx < -0.05) && !this.active) {
            this.active = true;
            TableViewCell.editingCell = this.cell;
            this.editingMode();
        }
        else {
            this.active = false;
            this.nonMode();
        }
        this.recognized = false;
        this.canceled = true;
    }
    editingMode() {
        let width = this.cell.actionView().props.frame.width;
        RN.Animated.spring(this.cell.contentViewMarginLeft, {
            toValue: -width,
            bounciness: 1.0,
            speed: 60.0,
        }).start();
        RN.Animated.spring(this.cell.contentViewMarginRight, {
            toValue: width,
            bounciness: 1.0,
            speed: 60.0,
        }).start();
    }
    nonMode() {
        RN.Animated.spring(this.cell.contentViewMarginLeft, {
            toValue: 0.0,
            bounciness: 0.9,
            speed: 60.0,
        }).start();
        RN.Animated.spring(this.cell.contentViewMarginRight, {
            toValue: 0.0,
            bounciness: 0.9,
            speed: 60.0,
        }).start();
        setTimeout(() => {
            this.cell.setState({
                editing: false,
            });
        }, 300);
    }
}

==> uxkit-0.0.3.tgz: package/built/UXKit/TableViewCell.js <==
/// <reference path="../../typings/tsd.d.ts"/>
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
import * as React from "react";
import * as RN from "react-native";
import { View } from "./View";
import { PixelLine } from "./PixelLine";
import { Image, ImageView } from "./ImageView";
import { Control } from "./Control";
import { TextButton } from "./Button";
import { PresetColor } from "./Types";
import { ControlEvents, TableViewCellAccessoryType, ImageRenderingMode } from "./Enum";
export class TableViewCellReusingValues {
    constructor() {
        this.top = new RN.Animated.Value(0);
        this.height = new RN.Animated.Value(0);
        this.other = {};
        this.topValue = 0;
        this.heightValue = 0;
        this.otherValues = {};
    }
}
class ContentControl extends Control {
    content() {
        return (React.createElement(RN.View, {style: { position: "absolute", left: 0, right: 0, top: 0, bottom: 0, backgroundColor: this.state.highlighted ? this.props.highlightColor : "#ffffff00" }}, this.props.children));
    }
}
/**
 * TableViewCell
 */
export class TableViewCell extends View {
    constructor(props) {
        super(props);
        this.visibleProps = {};
        this.data = {};
        this.loaded = false;
        this.contentViewMarginLeft = new RN.Animated.Value(0.0);
        this.contentViewMarginRight = new RN.Animated.Value(0.0);
        this.editImp = new TableViewCellEditImp(this);
    }
    view() {
        return (React.createElement(RN.View, {style: { backgroundColor: "#ffffff00" }}));
    }
    componentDidMount() {
        if (this.props.reusingValue !== undefined) {
            this.props.reusingValue.other.reusingCell = this;
        }
    }
    accessoryView() {
        if (this.visibleProps.accessoryType === TableViewCellAccessoryType.DisclosureIndicator) {
            return (React.createElement(ImageView, {image: Image.resource(require("./Assets/ux_disclosureIndicator@2x.png")), frame: { cy: 0, mx: 0, width: 28 }}));
        }
        else if (this.visibleProps.accessoryType === TableViewCellAccessoryType.Checkmark) {
            return (React.createElement(ImageView, {image: Image.resource(require("./Assets/ux_checkmark@2x.png")).imageWithRenderingMode(ImageRenderingMode.Template), frame: { cy: 0, mx: 0, width: 28 }}));
        }
        else {
            return null;
        }
    }
    separatorView() {
        let left = this.props.tableView.props.separatorInset ? this.props.tableView.props.separatorInset.left : 0.0;
        let right = this.props.tableView.props.separatorInset ? this.props.tableView.props.separatorInset.right : 0.0;
        return (React.createElement(PixelLine, {left: left, right: right, bottom: 0}));
    }
    render() {
        if (this.props.tableView.props.allowsSelection === false) {
            return this.view();
        }
        if (this.props.tableView.props.allowsEditing && this.canPerformAction() !== false) {
            let selectedBackgroundColor = this.state ? this.state.selectedBackgroundColor : undefined;
            let editing = this.state ? this.state.editing : false;
            return (React.createElement(RN.View, {style: { flex: 1, backgroundColor: selectedBackgroundColor }}, editing ? this.actionView() : null, React.createElement(RN.Animated.View, __assign({style: { flex: 1, flexDirection: "row", backgroundColor: selectedBackgroundColor === undefined ? this.props.backgroundColor : "#ffffff00", marginLeft: this.contentViewMarginLeft, marginRight: this.contentViewMarginRight }}, this.editImp.requestResponder()), React.createElement(RN.View, {style: { flex: 1, flexDirection: "column", backgroundColor: "#ffffff00" }}, this.view(), this.separatorView()), this.accessoryView())));
        }
        else {
            return (React.createElement(ContentControl, {frame: { x: 0, y: 0, mx: 0, my: 0 }, delaysContentTouches: true, highlightColor: this.visibleProps.selectionColor ? this.visibleProps.selectionColor : "#e2e2e2", contentHorizontalAlignment: "left", contentVerticalAlignment: "top", handler: (event) => {
                if (event == ControlEvents.TouchUpInside) {
                    this.onSelected();
                }
            }}, this.view(), this.accessoryView(), this.separatorView()));
        }
    }
    reload() {
        if (this.props.reusingValue !== undefined) {
            this.visibleProps = !!this.props.reusingValue.other.arguments.visibleProps ? this.props.reusingValue.other.arguments.visibleProps : {};
            this.data = !!this.props.reusingValue.other.arguments.cellData ? this.props.reusingValue.other.arguments.cellData : {};
            this.forceUpdate();
        }
        this.loaded = true;
    }
    onSelected() {
        if (TableViewCell.editingCell && TableViewCell.editingCell.editImp && TableViewCell.editingCell.editImp.active) {
            TableViewCell.editingCell.endEditing();
            return;
        }
        this.props.tableView.hideIndicatorView(false);
        this.props.tableView && this.props.tableView.props.delegate && this.props.tableView.props.delegate.didSelectRowAtIndexPath && this.props.tableView.props.delegate.didSelectRowAtIndexPath(this.props.tableView, this.props.reusingValue.other.indexPath);
    }
    actionView() {
        return (React.createElement(View, {frame: { y: 0, my: 0, mx: 0, width: 66 }}, React.createElement(TextButton, {backgroundColor: PresetColor.destroyColor, tintColor: "white", title: "删除", style: { flex: 1 }, handler: (event) => {
            if (event === ControlEvents.TouchUpInside) {
                this.onDelete();
            }
        }})));
    }
    canPerformAction() {
        return true;
    }
    endEditing() {
        if (this.editImp.active) {
            this.editImp.end(0, 0);
        }
    }
    onDelete() {
        this.endEditing();
    }
}
TableViewCell.defaultProps = Object.assign({}, View.defaultProps, {
    backgroundColor: "#ffffff",
    userInteractionEnabled: true,
});
// editing
TableViewCell.editingCell = undefined;
/**
 * TableViewCellEditImp
 */
class TableViewCellEditImp {
    constructor(cell) {
        this.recognized = false;
        this.canceled = false;
        this.prevCanceled = false;
        this.active = false;
        this.cell = cell;
        this.panResponder = RN.PanResponder.create(this.panHandlers());
    }
    requestResponder() {
        return this.panResponder.panHandlers;
    }
    panHandlers() {
        return {
            onStartShouldSetPanResponder: (event, state) => {
                if (event.nativeEvent.pageX < 44) {
                    return false;
                }
                return true;
            },
            onStartShouldSetPanResponderCapture: (event, state) => {
                if (event.nativeEvent.pageX < this.cell.props.backTouchingArea) {
                    return false;
                }
                return true;
            },
            onMoveShouldSetPanResponder: (event, state) => {
                if (event.nativeEvent.pageX < this.cell.props.backTouchingArea) {
                    return false;
                }
                return true;
            },
            onMoveShouldSetPanResponderCapture: (event, state) => {
                if (event.nativeEvent.pageX < this.cell.props.backTouchingArea) {
                    return false;
                }
                return true;
            },
            onPanResponderGrant: (event, state) => {
                if (this.active) {
                    return;
                }
                this.prevCanceled = false;
                if (TableViewCell.editingCell !== undefined) {
                    this.prevCanceled = true;
                    TableViewCell.editingCell.endEditing();
                    TableViewCell.editingCell = undefined;
                }
                this.recognized = false;
                this.canceled = false;
                clearTimeout(this.highlightTimer);
                this.highlightTimer = setTimeout(() => {
                    if (!this.canceled) {
                        this.cell.setState({
                            selectedBackgroundColor: "#e2e2e2"
                        });
                    }
                }, 100);
            },
            onPanResponderMove: (event, state) => {
                if (this.active) {
                    return;
                }
                if (Math.abs(state.dy) < 11.0 && Math.abs(state.dx) > 4.0) {
                    if (!this.recognized) {
                        clearTimeout(this.highlightTimer);
                        this.cell.setState({
                            selectedBackgroundColor: undefined,
                            editing: true,
                        });
                    }
                    this.recognized = true;
                }
                if (this.recognized) {
                    this.move(state.dx);
                }
            },
            onPanResponderTerminationRequest: (event, state) => {
                if (Math.abs(state.dy) < 11.0 && Math.abs(state.dx) < 4.0) {
                    return false;
                }
                return !this.recognized;
            },
            onPanResponderRelease: (event, state) => {
                if (!this.recognized && !this.active && Math.abs(state.dx) < 8.0 && Math.abs(state.dy) < 8.0) {
                    !this.prevCanceled && this.cell.onSelected();
                }
                this.end(state.dx, state.vx);
            },
            onPanResponderTerminate: (event, state) => {
                this.end(state.dx, state.vx);
            },
        };
    }
    move(dx) {
        let width = this.cell.actionView().props.frame.width;
        let val = Math.max(-width, Math.min(15.0, dx));
        this.cell.contentViewMarginLeft.setValue(val);
        this.cell.contentViewMarginRight.setValue(-val);
    }
    end(dx, vx) {
        let width = this.cell.actionView().props.frame.width;
        this.cell.setState({
            selectedBackgroundColor: undefined,
        });
        if (this.recognized && (-dx > width / 2.0 || vx < -0.05) && !this.active) {
            this.active = true;
            TableViewCell.editingCell = this.cell;
            this.editingMode();
        }
        else {
            this.active = false;
            this.nonMode();
        }
        this.recognized = false;
        this.canceled = true;
    }
    editingMode() {
        let width = this.cell.actionView().props.frame.width;
        RN.Animated.spring(this.cell.contentViewMarginLeft, {
            toValue: -width,
            bounciness: 1.0,
            speed: 60.0,
        }).start();
        RN.Animated.spring(this.cell.contentViewMarginRight, {
            toValue: width,
            bounciness: 1.0,
            speed: 60.0,
        }).start();
    }
    nonMode() {
        RN.Animated.spring(this.cell.contentViewMarginLeft, {
            toValue: 0.0,
            bounciness: 0.9,
            speed: 60.0,
        }).start();
        RN.Animated.spring(this.cell.contentViewMarginRight, {
            toValue: 0.0,
            bounciness: 0.9,
            speed: 60.0,
        }).start();
        setTimeout(() => {
            this.cell.setState({
                editing: false,
            });
        }, 300);
    }
}
